import React, { useEffect, useRef } from "react";
import PropTypes from "prop-types";
export default function BackdropModal(props) {
  const ref = useRef(null);
  const { onClickOutside, open, children } = props;
  useEffect(() => {
    const handleClickOutside = (event) => {
      if (ref.current && !ref.current.contains(event.target)) {
        onClickOutside && onClickOutside();
      }
    };
    document.addEventListener("click", handleClickOutside, true);
    return () => {
      document.removeEventListener("click", handleClickOutside, true);
    };
  }, [onClickOutside]);
  if (!open) return null;
  return (
    <div className="modal-backdrop-style">
      <div
        ref={ref}
        className="modal-view"
        style={{
          transform: open ? "translateY(0)" : "translateY(-100vh)",
          opacity: open ? 1 : 0,
        }}
      >
        {children}
      </div>
    </div>
  );
}
BackdropModal.propTypes = {
  onClickOutside: PropTypes.func.isRequired,
  open: PropTypes.bool.isRequired,
  children: PropTypes.element.isRequired,
};